#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'settings.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGS_H
#define UI_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <kpluralhandlingspinbox.h>

QT_BEGIN_NAMESPACE

class Ui_SettingsWidget
{
public:
    QGridLayout *gridLayout;
    QGroupBox *kbuttongroup1;
    QVBoxLayout *vboxLayout;
    QTreeView *tealistTreeView;
    QHBoxLayout *hboxLayout;
    QToolButton *newButton;
    QToolButton *removeButton;
    QToolButton *upButton;
    QToolButton *downButton;
    QSpacerItem *spacerItem;
    QGroupBox *teaPropertiesGroup;
    QGridLayout *gridLayout1;
    QLabel *label;
    QLineEdit *teaNameEdit;
    QLabel *label_7;
    QSpinBox *minutesSpin;
    QLabel *label_3;
    QSpinBox *secondsSpin;
    QLabel *label_4;
    QSpacerItem *spacerItem1;
    QGroupBox *kbuttongroup2;
    QVBoxLayout *verticalLayout;
    QCheckBox *popupCheckBox;
    QHBoxLayout *hboxLayout1;
    QSpacerItem *spacerItem2;
    QCheckBox *autohideCheckBox;
    KPluralHandlingSpinBox *autohideSpinBox;
    QSpacerItem *spacerItem3;
    QHBoxLayout *hboxLayout2;
    QCheckBox *reminderCheckBox;
    KPluralHandlingSpinBox *reminderSpinBox;
    QSpacerItem *spacerItem4;
    QCheckBox *visualizeCheckBox;

    void setupUi(QWidget *SettingsWidget)
    {
        if (SettingsWidget->objectName().isEmpty())
            SettingsWidget->setObjectName(QStringLiteral("SettingsWidget"));
        SettingsWidget->resize(599, 535);
        gridLayout = new QGridLayout(SettingsWidget);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        kbuttongroup1 = new QGroupBox(SettingsWidget);
        kbuttongroup1->setObjectName(QStringLiteral("kbuttongroup1"));
        vboxLayout = new QVBoxLayout(kbuttongroup1);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        vboxLayout->setContentsMargins(-1, 0, -1, -1);
        tealistTreeView = new QTreeView(kbuttongroup1);
        tealistTreeView->setObjectName(QStringLiteral("tealistTreeView"));
        tealistTreeView->setRootIsDecorated(false);
        tealistTreeView->setItemsExpandable(false);

        vboxLayout->addWidget(tealistTreeView);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        newButton = new QToolButton(kbuttongroup1);
        newButton->setObjectName(QStringLiteral("newButton"));
        QIcon icon;
        icon.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        newButton->setIcon(icon);
        newButton->setAutoRaise(true);

        hboxLayout->addWidget(newButton);

        removeButton = new QToolButton(kbuttongroup1);
        removeButton->setObjectName(QStringLiteral("removeButton"));
        removeButton->setEnabled(true);
        removeButton->setAutoRaise(true);

        hboxLayout->addWidget(removeButton);

        upButton = new QToolButton(kbuttongroup1);
        upButton->setObjectName(QStringLiteral("upButton"));
        upButton->setEnabled(true);
        upButton->setAutoRaise(true);

        hboxLayout->addWidget(upButton);

        downButton = new QToolButton(kbuttongroup1);
        downButton->setObjectName(QStringLiteral("downButton"));
        downButton->setEnabled(true);
        downButton->setAutoFillBackground(false);
        downButton->setIcon(icon);
        downButton->setAutoRaise(true);

        hboxLayout->addWidget(downButton);

        spacerItem = new QSpacerItem(1, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout->addLayout(hboxLayout);


        gridLayout->addWidget(kbuttongroup1, 0, 0, 2, 1);

        teaPropertiesGroup = new QGroupBox(SettingsWidget);
        teaPropertiesGroup->setObjectName(QStringLiteral("teaPropertiesGroup"));
        teaPropertiesGroup->setEnabled(false);
        gridLayout1 = new QGridLayout(teaPropertiesGroup);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        label = new QLabel(teaPropertiesGroup);
        label->setObjectName(QStringLiteral("label"));

        gridLayout1->addWidget(label, 0, 0, 1, 1);

        teaNameEdit = new QLineEdit(teaPropertiesGroup);
        teaNameEdit->setObjectName(QStringLiteral("teaNameEdit"));
        teaNameEdit->setEnabled(false);

        gridLayout1->addWidget(teaNameEdit, 0, 1, 1, 4);

        label_7 = new QLabel(teaPropertiesGroup);
        label_7->setObjectName(QStringLiteral("label_7"));

        gridLayout1->addWidget(label_7, 1, 0, 1, 1);

        minutesSpin = new QSpinBox(teaPropertiesGroup);
        minutesSpin->setObjectName(QStringLiteral("minutesSpin"));
        minutesSpin->setEnabled(false);
        minutesSpin->setMaximum(1440);

        gridLayout1->addWidget(minutesSpin, 1, 1, 1, 1);

        label_3 = new QLabel(teaPropertiesGroup);
        label_3->setObjectName(QStringLiteral("label_3"));

        gridLayout1->addWidget(label_3, 1, 2, 1, 1);

        secondsSpin = new QSpinBox(teaPropertiesGroup);
        secondsSpin->setObjectName(QStringLiteral("secondsSpin"));
        secondsSpin->setEnabled(false);
        secondsSpin->setMaximum(59);

        gridLayout1->addWidget(secondsSpin, 1, 3, 1, 1);

        label_4 = new QLabel(teaPropertiesGroup);
        label_4->setObjectName(QStringLiteral("label_4"));

        gridLayout1->addWidget(label_4, 1, 4, 1, 1);


        gridLayout->addWidget(teaPropertiesGroup, 0, 1, 1, 1);

        spacerItem1 = new QSpacerItem(21, 81, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(spacerItem1, 1, 1, 1, 1);

        kbuttongroup2 = new QGroupBox(SettingsWidget);
        kbuttongroup2->setObjectName(QStringLiteral("kbuttongroup2"));
        verticalLayout = new QVBoxLayout(kbuttongroup2);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        popupCheckBox = new QCheckBox(kbuttongroup2);
        popupCheckBox->setObjectName(QStringLiteral("popupCheckBox"));
        popupCheckBox->setChecked(true);

        verticalLayout->addWidget(popupCheckBox);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        spacerItem2 = new QSpacerItem(16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem2);

        autohideCheckBox = new QCheckBox(kbuttongroup2);
        autohideCheckBox->setObjectName(QStringLiteral("autohideCheckBox"));
        autohideCheckBox->setEnabled(true);
        autohideCheckBox->setChecked(false);

        hboxLayout1->addWidget(autohideCheckBox);

        autohideSpinBox = new KPluralHandlingSpinBox(kbuttongroup2);
        autohideSpinBox->setObjectName(QStringLiteral("autohideSpinBox"));
        autohideSpinBox->setEnabled(false);
        autohideSpinBox->setMinimumSize(QSize(120, 0));
        autohideSpinBox->setMinimum(1);
        autohideSpinBox->setMaximum(300);
        autohideSpinBox->setValue(30);

        hboxLayout1->addWidget(autohideSpinBox);

        spacerItem3 = new QSpacerItem(151, 24, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem3);


        verticalLayout->addLayout(hboxLayout1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName(QStringLiteral("hboxLayout2"));
        reminderCheckBox = new QCheckBox(kbuttongroup2);
        reminderCheckBox->setObjectName(QStringLiteral("reminderCheckBox"));

        hboxLayout2->addWidget(reminderCheckBox);

        reminderSpinBox = new KPluralHandlingSpinBox(kbuttongroup2);
        reminderSpinBox->setObjectName(QStringLiteral("reminderSpinBox"));
        reminderSpinBox->setEnabled(false);
        reminderSpinBox->setMinimumSize(QSize(120, 0));
        reminderSpinBox->setMinimum(1);
        reminderSpinBox->setMaximum(300);
        reminderSpinBox->setValue(60);

        hboxLayout2->addWidget(reminderSpinBox);

        spacerItem4 = new QSpacerItem(181, 25, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout2->addItem(spacerItem4);


        verticalLayout->addLayout(hboxLayout2);


        gridLayout->addWidget(kbuttongroup2, 2, 0, 1, 2);

        visualizeCheckBox = new QCheckBox(SettingsWidget);
        visualizeCheckBox->setObjectName(QStringLiteral("visualizeCheckBox"));
        visualizeCheckBox->setChecked(true);

        gridLayout->addWidget(visualizeCheckBox, 3, 0, 1, 2);


        retranslateUi(SettingsWidget);
        QObject::connect(autohideCheckBox, SIGNAL(toggled(bool)), autohideSpinBox, SLOT(setEnabled(bool)));
        QObject::connect(reminderCheckBox, SIGNAL(toggled(bool)), reminderSpinBox, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(SettingsWidget);
    } // setupUi

    void retranslateUi(QWidget *SettingsWidget)
    {
        kbuttongroup1->setTitle(tr2i18n("Tea List", Q_NULLPTR));
        newButton->setText(tr2i18n("N", "KDE::DoNotExtract"));
        removeButton->setText(tr2i18n("D", "KDE::DoNotExtract"));
        upButton->setText(tr2i18n("U", "KDE::DoNotExtract"));
        downButton->setText(tr2i18n("D", "KDE::DoNotExtract"));
        teaPropertiesGroup->setTitle(tr2i18n("Tea Properties", Q_NULLPTR));
        label->setText(tr2i18n("Name", Q_NULLPTR));
        label_7->setText(tr2i18n("Time", Q_NULLPTR));
        label_3->setText(tr2i18n("min", Q_NULLPTR));
        label_4->setText(tr2i18n("sec", Q_NULLPTR));
        kbuttongroup2->setTitle(tr2i18n("Action", Q_NULLPTR));
        popupCheckBox->setText(tr2i18n("Popup", Q_NULLPTR));
        autohideCheckBox->setText(tr2i18n("Auto hide popup after", Q_NULLPTR));
        reminderCheckBox->setText(tr2i18n("Reminder every", Q_NULLPTR));
        visualizeCheckBox->setText(tr2i18n("Visualize progress in icon tray", Q_NULLPTR));
        Q_UNUSED(SettingsWidget);
    } // retranslateUi

};

namespace Ui {
    class SettingsWidget: public Ui_SettingsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGS_H

